@@ -4,6 +4,10 @@ import re
 import sys
 import itertools
 import json
+try:
+    import xmlrpclib as xmlrpc_client
+except ImportError:
+    import xmlrpc.client as xmlrpc_client
 
 import lxml.html
 from picklecache import cache
@@ -47,36 +51,13 @@ def gitorious():
     for repository in project.xpath('//repository[owner[text()="tlevine"]]'):
         yield 'https' + repository.xpath('clone_url/text()')[0][3:-4]
 
+def pypi():
+    client = xmlrpc_client.ServerProxy('http://pypi.python.org/pypi')
+    for role, package in client.user_packages('tlevine'):
+        yield 'https://pypi.python.org/pypi/%s' % package
+
 def manual():
     return [
-        'https://pypi.python.org/pypi/blizzard',
-        'https://pypi.python.org/pypi/bugs-everywhere',
-        'https://pypi.python.org/pypi/cereal_jar',
-        'https://pypi.python.org/pypi/craigsgenerator',
-        'https://pypi.python.org/pypi/ddpy',
-        'https://pypi.python.org/pypi/dicti',
-        'https://pypi.python.org/pypi/download_ckan',
-        'https://pypi.python.org/pypi/download_junar',
-        'https://pypi.python.org/pypi/download_opendataphilly',
-        'https://pypi.python.org/pypi/download_opendatasoft',
-        'https://pypi.python.org/pypi/download_socrata',
-        'https://pypi.python.org/pypi/dumptruck',
-        'https://pypi.python.org/pypi/get-cached',
-        'https://pypi.python.org/pypi/juliadown',
-        'https://pypi.python.org/pypi/jumble',
-        'https://pypi.python.org/pypi/mailfest-scoreboard',
-        'https://pypi.python.org/pypi/picklecache',
-        'https://pypi.python.org/pypi/pickle-warehouse',
-        'https://pypi.python.org/pypi/randomsleep',
-        'https://pypi.python.org/pypi/scarsdale-property-inquiry',
-        'https://pypi.python.org/pypi/scraperwiki_local',
-        'https://pypi.python.org/pypi/sheetmusic',
-        'https://pypi.python.org/pypi/sliding_window',
-        'https://pypi.python.org/pypi/socrata',
-        'https://pypi.python.org/pypi/special_snowflake',
-        'https://pypi.python.org/pypi/tlevine',
-        'https://pypi.python.org/pypi/to_function',
-        'https://pypi.python.org/pypi/treasuryio',
         'https://chrome.google.com/webstore/detail/simple-webcam/cejgmnpegppdhkmmgmdobfelcdgfhkmo?hl=en',
     ]
 
